Change Log
==========
This file documents the changes between each released version of StratumGS.


Unreleased
----------
These are the changes that have been made to the current working version since
the previous release.


0.1.1 - 2016-05-28
------------------
Adds a configuration file to the server.

Added
^^^^^
- Requirements files for documentation and development
- Initial configuration file for the server
- This change log

Updated
^^^^^^^
- Added classifiers, an entry point, and keywords to setup.py
- Update the project URL in setup.py
- Updated the code to be PEP8 conformant
- Included version number in documentation


0.1.0 - 2016-05-13
------------------
The initial version of the project.

Added
^^^^^
- Set up project structure
- Initial web interface design
- Set up project as a Python module
- Documentation for the project
- TicTacToe game engine
